#  
Function FolderCreate($Folder){
	if(!(Test-Path $Folder))
	{
		New-Item -Path $Folder -ItemType "directory"
	}
}

#########################   AD  ###################################
$objSearcher = New-Object System.DirectoryServices.DirectorySearcher
$objSearcher.SearchRoot = "LDAP://DC="C  ",DC=ru"
$objSearcher.Filter = "(&(objectCategory=person)(!userAccountControl:1.2.840.113556.1.4.803:=2))"
$users = $objSearcher.FindAll()
#   
$users.Count 
$users | ForEach-Object {
   $user = $_.Properties
   New-Object PsObject -Property @{
    = [string]$user.userprincipalname
    = [string]$user.cn
    }
} | Export-Csv -Encoding utf8 -Path "File Access QV\list_users.csv"

#########   ,   ,   ################
#############          #####################
$FolderDestGroup = "\File Access QV"

$objSearcher = New-Object System.DirectoryServices.DirectorySearcher
$objSearcher.SearchRoot = "LDAP://OU=     AD   "
$objSearcher.Filter = "(&(objectCategory=Group)(!userAccountControl:1.2.840.113556.1.4.803:=2))"
$users = $objSearcher.FindAll()
#   
$users.Count 
[array]$SearchGroups = 
$users | ForEach-Object {
   $user = $_.Properties
   New-Object PsObject -Property @{
    = [string]$user.cn
    }

} | Out-String -Stream

#  LDAP
$DNService = " LDAP"
$user = ""
$pswd = ""

#  ,   AD
$RootObject = New-Object -TypeName System.DirectoryServices.DirectoryEntry($DNService,$user,$pswd,'FastBind')

#     
$GroupResult = foreach($CurrentGroup in $SearchGroups | select -unique)
{
	$LDAPQuery = "(memberOf=CN=" + $CurrentGroup + ",OU=     AD   "
	$LDAPQueryObject = New-Object -TypeName System.DirectoryServices.DirectorySearcher($RootObject,$LDAPQuery)
	$LDAPResult = $LDAPQueryObject.FindAll()
	
	foreach($CurrentUser in $LDAPResult)
	{
		$Result = $CurrentGroup + "`t" + $CurrentUser.Path
		echo $Result
	}
}

$GroupResult | Out-File -filepath ($FolderDestGroup + "\GroupMember.csv")

################      ###################

#    
$Directories = Get-Content "\File Access QV\Directories.txt";

foreach($Dir in $Directories)
{
	#  
	$FolderSource = $Dir

	#    
	$Num = $Dir.LastIndexOf("\")+1
	$FDest = $Dir.substring($Num)
	
	$FolderDest = "\File Access QV\Access_" + $FDest
	$FolderDestQVD = "\FileAccess\Access_" + $FDest

	#   ,     - 
	FolderCreate -Folder $FolderDest
	FolderCreate -Folder $FolderDestQVD

	#         
	$resc = gci $FolderSource  -recurse

	#        
	$FileAccessResult = foreach($r in $resc)
	{
		$s = get-acl $r.fullname

		foreach($inherit in $s.Access)
	    {
			$inherit | add-member -membertype noteproperty  -name Path -value $r.fullname -passthru | select *
		}
	}

	#        
	$FileAccessResult | Export-Csv -Encoding "Unicode" -Path ($FolderDest + "\FileAccess.csv") -Delimiter "`t"

	# QlikView        
	$sQVDistrExe = "C:\Program Files\QlikView\Qv.exe"
	$Var = 	"/r /vvFileAccessDir=" + $FDest + " "
	$Report = "\Extractor FileAccess.qvw"
	$reload = [diagnostics.process]::start($sQVDistrExe, $Var + $Report)
	$reload.WaitForExit()
	Start-sleep -milliseconds 5000
}

# 
$sQVDistrExe = "C:\Program Files\QlikView\Qv.exe"
$Var = 	"/r "
$Report = "\FileAccess.qvw"
$reload = [diagnostics.process]::start($sQVDistrExe, $Var + $Report)